@@ -319,17 +319,16 @@ c
  570  if (itape.gt.0) write (itape,600) is,rsq(is)
  580  continue
       return
- 590  format(   15h0eigensolution i2,    1h:)
- 600  format(   15h eigensolution i2,   23h   r**2  =  1 - e**2  =g12.4)
- 610  format(   15h     iteration i2,   23h   r**2  =  1 - e**2  =g12.4)
- 620  format(   41h ierr=1: sum of weights (w) not positive.)
- 630  format(   29h ierr=2: y has zero variance.)
- 640  format(   14h ierr=3: ty(.,i2,   20h) has zero variance.)
- 650  format(   11h ierr=4: l(i2,   18h) must be nonzero.)
- 660  format(   29h ierr=5: at least one l(1)-l(i2,   18h) must be nonze
-     1ro.)
- 670  format(   11h ierr=6: l(i2,    3h) =g12.4,   30h must be in the ra
-     1nge (-5, 5).)
+ 590  format('0eigensolution ',i2, ':')
+ 600  format(' eigensolution ',i2, 'h   r**2  =  1 - e**2  =',g12.4)
+ 610  format('     iteration ',i2, 'h   r**2  =  1 - e**2  =',g12.4)
+ 620  format(' ierr=1: sum of weights (w) not positive.')
+ 630  format(' ierr=2: y has zero variance.')
+ 640  format(' ierr=3: ty(.',i2,') has zero variance.')
+ 650  format(' ierr=4: l(',i2,   ') must be nonzero.')
+ 660  format(' ierr=5: at least one l(1)-l(',i2,') must be nonzero.')
+ 670  format(' ierr=6: l(',i2,    ') =',g12.4,
+     1 ' must be in the range (-5, 5).')
       end
       subroutine model (p,n,y,w,l,tx,ty,f,t,m,z)
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
